@@ -157,7 +157,7 @@ class VagasDotComCandidateGHLoad:
             )
 
         candidate_migration_uuid = None
-        if candidate_migration or candidate_migration.get("count", 0) > 0:
+        if candidate_migration and candidate_migration.get("count", 0) > 0:
             candidate_migration_uuid = candidate_migration["results"][0]["id"]
 
         return self.http.post(
